pub struct ToolCallInfo {
pub id: String,
pub name: String,
pub args: Value,
}Expand description
Information about a tool call requested by the model.
Yielded as AgentEvent::ToolCall when the model requests a tool invocation.
At this point the tool has not yet been executed.
Fields
id: Stringname: Stringargs: ValueTrait Implementations
Sourceimpl Clone for ToolCallInfo
impl Clone for ToolCallInfo
Sourcefn clone(&self) -> ToolCallInfo
fn clone(&self) -> ToolCallInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ToolCallInfo
impl RefUnwindSafe for ToolCallInfo
impl Send for ToolCallInfo
impl Sync for ToolCallInfo
impl Unpin for ToolCallInfo
impl UnsafeUnpin for ToolCallInfo
impl UnwindSafe for ToolCallInfo