ApiRequest builder module.
Provides a safe, chainable request builder that wraps the internal
crate::raw::ChatCompletionRequest.
Structs
- ApiRequest
- A safe, chainable request builder that wraps
ChatCompletionRequest.
ApiRequest builder module.
Provides a safe, chainable request builder that wraps the internal
crate::raw::ChatCompletionRequest.
ChatCompletionRequest.