Summarizer

Trait Summarizer 

pub trait Summarizer: Send + Sync {
    // Required methods
    fn should_summarize(&self, history: &[Message]) -> bool;
    fn summarize(&self, history: &mut Vec<Message>) -> Option<Message>;
}
Summarizer trait:

  • should_summarize checks whether current history should be summarized
  • summarize mutates the history to replace older messages with a single short system summary message

Required Methods

fn should_summarize(&self, history: &[Message]) -> bool

Return true if history should be summarized now.

fn summarize(&self, history: &mut Vec<Message>) -> Option<Message>

Perform summarization by mutating history. If a summary was created and applied, return Some(Message) representing the inserted summary message. If nothing was done, return None.

Implementors